Change class

The Change structure describes the changes AWS CloudFormation will perform if you execute the change set.

Constructors

Change({ResourceChange? resourceChange, ChangeType? type})
Change.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
resourceChange → ResourceChange?
A ResourceChange structure that describes the resource and action that AWS CloudFormation will perform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ChangeType?
The type of entity that AWS CloudFormation changes. Currently, the only entity type is Resource.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited