ChangeSetSummary class

The ChangeSetSummary structure describes a change set, its status, and the stack with which it's associated.

Constructors

ChangeSetSummary({String? changeSetId, String? changeSetName, DateTime? creationTime, String? description, ExecutionStatus? executionStatus, bool? includeNestedStacks, String? parentChangeSetId, String? rootChangeSetId, String? stackId, String? stackName, ChangeSetStatus? status, String? statusReason})
ChangeSetSummary.fromXml(XmlElement elem)
factory

Properties

changeSetId → String?
The ID of the change set.
final
changeSetName → String?
The name of the change set.
final
creationTime → DateTime?
The start time when the change set was created, in UTC.
final
description → String?
Descriptive information about the change set.
final
executionStatus → ExecutionStatus?
If the change set execution status is AVAILABLE, you can execute the change set. If you can’t execute the change set, the status indicates why. For example, a change set might be in an UNAVAILABLE state because AWS CloudFormation is still creating it or in an OBSOLETE state because the stack was already updated.
final
hashCode → int
The hash code for this object.
no setterinherited
includeNestedStacks → bool?
Specifies the current setting of IncludeNestedStacks for the change set.
final
parentChangeSetId → String?
The parent change set ID.
final
rootChangeSetId → String?
The root change set ID.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackId → String?
The ID of the stack with which the change set is associated.
final
stackName → String?
The name of the stack with which the change set is associated.
final
status → ChangeSetStatus?
The state of the change set, such as CREATE_IN_PROGRESS, CREATE_COMPLETE, or FAILED.
final
statusReason → String?
A description of the change set's status. For example, if your change set is in the FAILED state, AWS CloudFormation shows the error message.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited