DescribeChangeSetOutput class

The output for the DescribeChangeSet action.

Constructors

DescribeChangeSetOutput({List<Capability>? capabilities, String? changeSetId, String? changeSetName, List<Change>? changes, DateTime? creationTime, String? description, ExecutionStatus? executionStatus, bool? includeNestedStacks, String? nextToken, List<String>? notificationARNs, List<Parameter>? parameters, String? parentChangeSetId, RollbackConfiguration? rollbackConfiguration, String? rootChangeSetId, String? stackId, String? stackName, ChangeSetStatus? status, String? statusReason, List<Tag>? tags})
DescribeChangeSetOutput.fromXml(XmlElement elem)
factory

Properties

capabilities → List<Capability>?
If you execute the change set, the list of capabilities that were explicitly acknowledged when the change set was created.
final
changes → List<Change>?
A list of Change structures that describes the resources AWS CloudFormation changes if you execute the change set.
final
changeSetId → String?
The ARN of the change set.
final
changeSetName → String?
The name of the change set.
final
creationTime → DateTime?
The start time when the change set was created, in UTC.
final
description → String?
Information about the change set.
final
executionStatus → ExecutionStatus?
If the change set execution status is AVAILABLE, you can execute the change set. If you can’t execute the change set, the status indicates why. For example, a change set might be in an UNAVAILABLE state because AWS CloudFormation is still creating it or in an OBSOLETE state because the stack was already updated.
final
hashCode → int
The hash code for this object.
no setterinherited
includeNestedStacks → bool?
Verifies if IncludeNestedStacks is set to True.
final
nextToken → String?
If the output exceeds 1 MB, a string that identifies the next page of changes. If there is no additional page, this value is null.
final
notificationARNs → List<String>?
The ARNs of the Amazon Simple Notification Service (Amazon SNS) topics that will be associated with the stack if you execute the change set.
final
parameters → List<Parameter>?
A list of Parameter structures that describes the input parameters and their values used to create the change set. For more information, see the Parameter data type.
final
parentChangeSetId → String?
Specifies the change set ID of the parent change set in the current nested change set hierarchy.
final
rollbackConfiguration → RollbackConfiguration?
The rollback triggers for AWS CloudFormation to monitor during stack creation and updating operations, and for the specified monitoring period afterwards.
final
rootChangeSetId → String?
Specifies the change set ID of the root change set in the current nested change set hierarchy.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackId → String?
The ARN of the stack that is associated with the change set.
final
stackName → String?
The name of the stack that is associated with the change set.
final
status → ChangeSetStatus?
The current status of the change set, such as CREATE_IN_PROGRESS, CREATE_COMPLETE, or FAILED.
final
statusReason → String?
A description of the change set's status. For example, if your attempt to create a change set failed, AWS CloudFormation shows the error message.
final
tags → List<Tag>?
If you execute the change set, the tags that will be associated with the stack.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited