DescribeStackDriftDetectionStatusOutput class

Constructors

DescribeStackDriftDetectionStatusOutput({required StackDriftDetectionStatus detectionStatus, required String stackDriftDetectionId, required String stackId, required DateTime timestamp, String? detectionStatusReason, int? driftedStackResourceCount, StackDriftStatus? stackDriftStatus})
DescribeStackDriftDetectionStatusOutput.fromXml(XmlElement elem)
factory

Properties

detectionStatus → StackDriftDetectionStatus
The status of the stack drift detection operation.
final
detectionStatusReason → String?
The reason the stack drift detection operation has its current status.
final
driftedStackResourceCount → int?
Total number of stack resources that have drifted. This is NULL until the drift detection operation reaches a status of DETECTION_COMPLETE. This value will be 0 for stacks whose drift status is IN_SYNC.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackDriftDetectionId → String
The ID of the drift detection results of this operation.
final
stackDriftStatus → StackDriftStatus?
Status of the stack's actual configuration compared to its expected configuration.
final
stackId → String
The ID of the stack.
final
timestamp → DateTime
Time at which the stack drift detection operation was initiated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited