DescribeStackEventsOutput class

The output for a DescribeStackEvents action.

Constructors

DescribeStackEventsOutput({String? nextToken, List<StackEvent>? stackEvents})
DescribeStackEventsOutput.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
If the output exceeds 1 MB in size, a string that identifies the next page of events. If no additional page exists, this value is null.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackEvents → List<StackEvent>?
A list of StackEvents structures.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited