DescribeStackSetOperationOutput class

Constructors

DescribeStackSetOperationOutput({StackSetOperation? stackSetOperation})
DescribeStackSetOperationOutput.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackSetOperation → StackSetOperation?
The specified stack set operation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited