Export class

The Export structure describes the exported output values for a stack.

Constructors

Export({String? exportingStackId, String? name, String? value})
Export.fromXml(XmlElement elem)
factory

Properties

exportingStackId → String?
The stack that contains the exported output name and value.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of exported output value. Use this name and the Fn::ImportValue function to import the associated value into other stacks. The name is defined in the Export field in the associated stack's Outputs section.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String?
The value of the exported output, such as a resource physical ID. This value is defined in the Export field in the associated stack's Outputs section.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited