GetTemplateSummaryOutput class

The output for the GetTemplateSummary action.

Constructors

GetTemplateSummaryOutput({List<Capability>? capabilities, String? capabilitiesReason, List<String>? declaredTransforms, String? description, String? metadata, List<ParameterDeclaration>? parameters, List<ResourceIdentifierSummary>? resourceIdentifierSummaries, List<String>? resourceTypes, String? version})
GetTemplateSummaryOutput.fromXml(XmlElement elem)
factory

Properties

capabilities → List<Capability>?
The capabilities found within the template. If your template contains IAM resources, you must specify the CAPABILITY_IAM or CAPABILITY_NAMED_IAM value for this parameter when you use the CreateStack or UpdateStack actions with your template; otherwise, those actions return an InsufficientCapabilities error.
final
capabilitiesReason → String?
The list of resources that generated the values in the Capabilities response element.
final
declaredTransforms → List<String>?
A list of the transforms that are declared in the template.
final
description → String?
The value that is defined in the Description property of the template.
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → String?
The value that is defined for the Metadata property of the template.
final
parameters → List<ParameterDeclaration>?
A list of parameter declarations that describe various properties for each parameter.
final
resourceIdentifierSummaries → List<ResourceIdentifierSummary>?
A list of resource identifier summaries that describe the target resources of an import operation and the properties you can provide during the import to identify the target resources. For example, BucketName is a possible identifier property for an AWS::S3::Bucket resource.
final
resourceTypes → List<String>?
A list of all the template resource types that are defined in the template, such as AWS::EC2::Instance, AWS::Dynamo::Table, and Custom::MyCustomInstance.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String?
The AWS template format version, which identifies the capabilities of the template.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited