LoggingConfig class

Contains logging configuration information for a type.

Constructors

LoggingConfig({required String logGroupName, required String logRoleArn})
LoggingConfig.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
logGroupName → String
The Amazon CloudWatch log group to which CloudFormation sends error logging information when invoking the type's handlers.
final
logRoleArn → String
The ARN of the role that CloudFormation should assume when sending log entries to CloudWatch logs.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited