Output class

The Output data type.

Constructors

Output({String? description, String? exportName, String? outputKey, String? outputValue})
Output.fromXml(XmlElement elem)
factory

Properties

description → String?
User defined description associated with the output.
final
exportName → String?
The name of the export associated with the output.
final
hashCode → int
The hash code for this object.
no setterinherited
outputKey → String?
The key associated with the output.
final
outputValue → String?
The value associated with the output.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited