Parameter class

The Parameter data type.

Constructors

Parameter({String? parameterKey, String? parameterValue, String? resolvedValue, bool? usePreviousValue})
Parameter.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
parameterKey → String?
The key associated with the parameter. If you don't specify a key and value for a particular parameter, AWS CloudFormation uses the default value that is specified in your template.
final
parameterValue → String?
The input value associated with the parameter.
final
resolvedValue → String?
Read-only. The value that corresponds to a Systems Manager parameter key. This field is returned only for SSM parameter types in the template.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usePreviousValue → bool?
During a stack update, use the existing parameter value that the stack is using for a given parameter key. If you specify true, do not specify a parameter value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited