ParameterDeclaration class

The ParameterDeclaration data type.

Constructors

ParameterDeclaration({String? defaultValue, String? description, bool? noEcho, ParameterConstraints? parameterConstraints, String? parameterKey, String? parameterType})
ParameterDeclaration.fromXml(XmlElement elem)
factory

Properties

defaultValue → String?
The default value of the parameter.
final
description → String?
The description that is associate with the parameter.
final
hashCode → int
The hash code for this object.
no setterinherited
noEcho → bool?
Flag that indicates whether the parameter value is shown as plain text in logs and in the AWS Management Console.
final
parameterConstraints → ParameterConstraints?
The criteria that AWS CloudFormation uses to validate parameter values.
final
parameterKey → String?
The name that is associated with the parameter.
final
parameterType → String?
The type of parameter.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited