changeSource property
The group to which the CausingEntity value belongs. There are
five entity groups:
-
ResourceReferenceentities areRefintrinsic functions that refer to resources in the template, such as{ "Ref" : "MyEC2InstanceResource" }. -
ParameterReferenceentities areRefintrinsic functions that get template parameter values, such as{ "Ref" : "MyPasswordParameter" }. -
ResourceAttributeentities areFn::GetAttintrinsic functions that get resource attribute values, such as{ "Fn::GetAtt" : [ "MyEC2InstanceResource", "PublicDnsName" ] }. -
DirectModificationentities are changes that are made directly to the template. -
Automaticentities areAWS::CloudFormation::Stackresource types, which are also known as nested stacks. If you made no changes to theAWS::CloudFormation::Stackresource, AWS CloudFormation sets theChangeSourcetoAutomaticbecause the nested stack's template might have changed. Changes to a nested stack's template aren't visible to AWS CloudFormation until you run an update on the parent stack.
Implementation
final ChangeSource? changeSource;