target property
A ResourceTargetDefinition structure that describes the field
that AWS CloudFormation will change and whether the resource will be
recreated.
Implementation
final ResourceTargetDefinition? target;
A ResourceTargetDefinition structure that describes the field
that AWS CloudFormation will change and whether the resource will be
recreated.
final ResourceTargetDefinition? target;