ResourceTargetDefinition class

The field that AWS CloudFormation will change, such as the name of a resource's property, and whether the resource will be recreated.

Constructors

ResourceTargetDefinition({ResourceAttribute? attribute, String? name, RequiresRecreation? requiresRecreation})
ResourceTargetDefinition.fromXml(XmlElement elem)
factory

Properties

attribute → ResourceAttribute?
Indicates which resource attribute is triggering this update, such as a change in the resource attribute's Metadata, Properties, or Tags.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
If the Attribute value is Properties, the name of the property. For all other attributes, the value is null.
final
requiresRecreation → RequiresRecreation?
If the Attribute value is Properties, indicates whether a change to this property causes the resource to be recreated. The value can be Never, Always, or Conditionally. To determine the conditions for a Conditionally recreation, see the update behavior for that property in the AWS CloudFormation User Guide.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited