Stack class

The Stack data type.

Constructors

Stack({required DateTime creationTime, required String stackName, required StackStatus stackStatus, List<Capability>? capabilities, String? changeSetId, DateTime? deletionTime, String? description, bool? disableRollback, StackDriftInformation? driftInformation, bool? enableTerminationProtection, DateTime? lastUpdatedTime, List<String>? notificationARNs, List<Output>? outputs, List<Parameter>? parameters, String? parentId, String? roleARN, RollbackConfiguration? rollbackConfiguration, String? rootId, String? stackId, String? stackStatusReason, List<Tag>? tags, int? timeoutInMinutes})
Stack.fromXml(XmlElement elem)
factory

Properties

capabilities → List<Capability>?
The capabilities allowed in the stack.
final
changeSetId → String?
The unique ID of the change set.
final
creationTime → DateTime
The time at which the stack was created.
final
deletionTime → DateTime?
The time the stack was deleted.
final
description → String?
A user-defined description associated with the stack.
final
disableRollback → bool?
Boolean to enable or disable rollback on stack creation failures:
final
driftInformation → StackDriftInformation?
Information on whether a stack's actual configuration differs, or has drifted, from it's expected configuration, as defined in the stack template and any values specified as template parameters. For more information, see Detecting Unregulated Configuration Changes to Stacks and Resources.
final
enableTerminationProtection → bool?
Whether termination protection is enabled for the stack.
final
hashCode → int
The hash code for this object.
no setterinherited
lastUpdatedTime → DateTime?
The time the stack was last updated. This field will only be returned if the stack has been updated at least once.
final
notificationARNs → List<String>?
SNS topic ARNs to which stack related events are published.
final
outputs → List<Output>?
A list of output structures.
final
parameters → List<Parameter>?
A list of Parameter structures.
final
parentId → String?
For nested stacks--stacks created as resources for another stack--the stack ID of the direct parent of this stack. For the first level of nested stacks, the root stack is also the parent stack.
final
roleARN → String?
The Amazon Resource Name (ARN) of an AWS Identity and Access Management (IAM) role that is associated with the stack. During a stack operation, AWS CloudFormation uses this role's credentials to make calls on your behalf.
final
rollbackConfiguration → RollbackConfiguration?
The rollback triggers for AWS CloudFormation to monitor during stack creation and updating operations, and for the specified monitoring period afterwards.
final
rootId → String?
For nested stacks--stacks created as resources for another stack--the stack ID of the top-level stack to which the nested stack ultimately belongs.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackId → String?
Unique identifier of the stack.
final
stackName → String
The name associated with the stack.
final
stackStatus → StackStatus
Current status of the stack.
final
stackStatusReason → String?
Success/failure message associated with the stack status.
final
tags → List<Tag>?
A list of Tags that specify information about the stack.
final
timeoutInMinutes → int?
The amount of time within which stack creation should complete.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited