StackEvent class

The StackEvent data type.

Constructors

StackEvent({required String eventId, required String stackId, required String stackName, required DateTime timestamp, String? clientRequestToken, String? logicalResourceId, String? physicalResourceId, String? resourceProperties, ResourceStatus? resourceStatus, String? resourceStatusReason, String? resourceType})
StackEvent.fromXml(XmlElement elem)
factory

Properties

clientRequestToken → String?
The token passed to the operation that generated this event.
final
eventId → String
The unique ID of this event.
final
hashCode → int
The hash code for this object.
no setterinherited
logicalResourceId → String?
The logical name of the resource specified in the template.
final
physicalResourceId → String?
The name or unique identifier associated with the physical instance of the resource.
final
resourceProperties → String?
BLOB of the properties used to create the resource.
final
resourceStatus → ResourceStatus?
Current status of the resource.
final
resourceStatusReason → String?
Success/failure message associated with the resource.
final
resourceType → String?
Type of resource. (For more information, go to AWS Resource Types Reference in the AWS CloudFormation User Guide.)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackId → String
The unique ID name of the instance of the stack.
final
stackName → String
The name associated with a stack.
final
timestamp → DateTime
Time the status was updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited