StackInstance class

An AWS CloudFormation stack, in a specific account and Region, that's part of a stack set operation. A stack instance is a reference to an attempted or actual stack in a given account within a given Region. A stack instance can exist without a stack—for example, if the stack couldn't be created for some reason. A stack instance is associated with only one stack set. Each stack instance contains the ID of its associated stack set, as well as the ID of the actual stack and the stack status.

Constructors

StackInstance({String? account, StackDriftStatus? driftStatus, DateTime? lastDriftCheckTimestamp, String? organizationalUnitId, List<Parameter>? parameterOverrides, String? region, String? stackId, StackInstanceComprehensiveStatus? stackInstanceStatus, String? stackSetId, StackInstanceStatus? status, String? statusReason})
StackInstance.fromXml(XmlElement elem)
factory

Properties

account → String?
<code>Self-managed</code> permissions The name of the AWS account that the stack instance is associated with.
final
driftStatus → StackDriftStatus?
Status of the stack instance's actual configuration compared to the expected template and parameter configuration of the stack set to which it belongs.
final
hashCode → int
The hash code for this object.
no setterinherited
lastDriftCheckTimestamp → DateTime?
Most recent time when CloudFormation performed a drift detection operation on the stack instance. This value will be NULL for any stack instance on which drift detection has not yet been performed.
final
organizationalUnitId → String?
<code>Service-managed</code> permissions The organization root ID or organizational unit (OU) IDs that you specified for DeploymentTargets.
final
parameterOverrides → List<Parameter>?
A list of parameters from the stack set template whose values have been overridden in this stack instance.
final
region → String?
The name of the AWS Region that the stack instance is associated with.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackId → String?
The ID of the stack instance.
final
stackInstanceStatus → StackInstanceComprehensiveStatus?
The detailed status of the stack instance.
final
stackSetId → String?
The name or unique ID of the stack set that the stack instance is associated with.
final
status → StackInstanceStatus?
The status of the stack instance, in terms of its synchronization with its associated stack set.
final
statusReason → String?
The explanation for the specific status code that is assigned to this stack instance.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited