StackInstanceSummary class

The structure that contains summary information about a stack instance.

Constructors

StackInstanceSummary({String? account, StackDriftStatus? driftStatus, DateTime? lastDriftCheckTimestamp, String? organizationalUnitId, String? region, String? stackId, StackInstanceComprehensiveStatus? stackInstanceStatus, String? stackSetId, StackInstanceStatus? status, String? statusReason})
StackInstanceSummary.fromXml(XmlElement elem)
factory

Properties

account → String?
<code>Self-managed</code> permissions The name of the AWS account that the stack instance is associated with.
final
driftStatus → StackDriftStatus?
Status of the stack instance's actual configuration compared to the expected template and parameter configuration of the stack set to which it belongs.
final
hashCode → int
The hash code for this object.
no setterinherited
lastDriftCheckTimestamp → DateTime?
Most recent time when CloudFormation performed a drift detection operation on the stack instance. This value will be NULL for any stack instance on which drift detection has not yet been performed.
final
organizationalUnitId → String?
<code>Service-managed</code> permissions The organization root ID or organizational unit (OU) IDs that you specified for DeploymentTargets.
final
region → String?
The name of the AWS Region that the stack instance is associated with.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackId → String?
The ID of the stack instance.
final
stackInstanceStatus → StackInstanceComprehensiveStatus?
The detailed status of the stack instance.
final
stackSetId → String?
The name or unique ID of the stack set that the stack instance is associated with.
final
status → StackInstanceStatus?
The status of the stack instance, in terms of its synchronization with its associated stack set.
final
statusReason → String?
The explanation for the specific status code assigned to this stack instance.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited