StackResourceDriftInformation class

Contains information about whether the resource's actual configuration differs, or has drifted, from its expected configuration.

Constructors

StackResourceDriftInformation({required StackResourceDriftStatus stackResourceDriftStatus, DateTime? lastCheckTimestamp})
StackResourceDriftInformation.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastCheckTimestamp → DateTime?
When AWS CloudFormation last checked if the resource had drifted from its expected configuration.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackResourceDriftStatus → StackResourceDriftStatus
Status of the resource's actual configuration compared to its expected configuration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited