StackSetOperationResultSummary class

The structure that contains information about a specified operation's results for a given account in a given Region.

Constructors

StackSetOperationResultSummary({String? account, AccountGateResult? accountGateResult, String? organizationalUnitId, String? region, StackSetOperationResultStatus? status, String? statusReason})
StackSetOperationResultSummary.fromXml(XmlElement elem)
factory

Properties

account → String?
<code>Self-managed</code> permissions The name of the AWS account for this operation result.
final
accountGateResult → AccountGateResult?
The results of the account gate function AWS CloudFormation invokes, if present, before proceeding with stack set operations in an account
final
hashCode → int
The hash code for this object.
no setterinherited
organizationalUnitId → String?
<code>Service-managed</code> permissions The organization root ID or organizational unit (OU) IDs that you specified for DeploymentTargets.
final
region → String?
The name of the AWS Region for this operation result.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → StackSetOperationResultStatus?
The result status of the stack set operation for the given account in the given Region.
final
statusReason → String?
The reason for the assigned result status.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited