StackSetOperationSummary class

The structures that contain summary information about the specified operation.

Constructors

StackSetOperationSummary({StackSetOperationAction? action, DateTime? creationTimestamp, DateTime? endTimestamp, String? operationId, StackSetOperationStatus? status})
StackSetOperationSummary.fromXml(XmlElement elem)
factory

Properties

action → StackSetOperationAction?
The type of operation: CREATE, UPDATE, or DELETE. Create and delete operations affect only the specified stack instances that are associated with the specified stack set. Update operations affect both the stack set itself as well as all associated stack set instances.
final
creationTimestamp → DateTime?
The time at which the operation was initiated. Note that the creation times for the stack set operation might differ from the creation time of the individual stacks themselves. This is because AWS CloudFormation needs to perform preparatory work for the operation, such as dispatching the work to the requested Regions, before actually creating the first stacks.
final
endTimestamp → DateTime?
The time at which the stack set operation ended, across all accounts and Regions specified. Note that this doesn't necessarily mean that the stack set operation was successful, or even attempted, in each account or Region.
final
hashCode → int
The hash code for this object.
no setterinherited
operationId → String?
The unique ID of the stack set operation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → StackSetOperationStatus?
The overall status of the operation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited