StackSetSummary class

The structures that contain summary information about the specified stack set.

Constructors

StackSetSummary({AutoDeployment? autoDeployment, String? description, StackDriftStatus? driftStatus, DateTime? lastDriftCheckTimestamp, PermissionModels? permissionModel, String? stackSetId, String? stackSetName, StackSetStatus? status})
StackSetSummary.fromXml(XmlElement elem)
factory

Properties

autoDeployment → AutoDeployment?
<code>Service-managed</code> permissions Describes whether StackSets automatically deploys to AWS Organizations accounts that are added to a target organizational unit (OU).
final
description → String?
A description of the stack set that you specify when the stack set is created or updated.
final
driftStatus → StackDriftStatus?
Status of the stack set's actual configuration compared to its expected template and parameter configuration. A stack set is considered to have drifted if one or more of its stack instances have drifted from their expected template and parameter configuration.
final
hashCode → int
The hash code for this object.
no setterinherited
lastDriftCheckTimestamp → DateTime?
Most recent time when CloudFormation performed a drift detection operation on the stack set. This value will be NULL for any stack set on which drift detection has not yet been performed.
final
permissionModel → PermissionModels?
Describes how the IAM roles required for stack set operations are created.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackSetId → String?
The ID of the stack set.
final
stackSetName → String?
The name of the stack set.
final
status → StackSetStatus?
The status of the stack set.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited