StackSummary class

The StackSummary Data Type

Constructors

StackSummary({required DateTime creationTime, required String stackName, required StackStatus stackStatus, DateTime? deletionTime, StackDriftInformationSummary? driftInformation, DateTime? lastUpdatedTime, String? parentId, String? rootId, String? stackId, String? stackStatusReason, String? templateDescription})
StackSummary.fromXml(XmlElement elem)
factory

Properties

creationTime → DateTime
The time the stack was created.
final
deletionTime → DateTime?
The time the stack was deleted.
final
driftInformation → StackDriftInformationSummary?
Summarizes information on whether a stack's actual configuration differs, or has drifted, from it's expected configuration, as defined in the stack template and any values specified as template parameters. For more information, see Detecting Unregulated Configuration Changes to Stacks and Resources.
final
hashCode → int
The hash code for this object.
no setterinherited
lastUpdatedTime → DateTime?
The time the stack was last updated. This field will only be returned if the stack has been updated at least once.
final
parentId → String?
For nested stacks--stacks created as resources for another stack--the stack ID of the direct parent of this stack. For the first level of nested stacks, the root stack is also the parent stack.
final
rootId → String?
For nested stacks--stacks created as resources for another stack--the stack ID of the top-level stack to which the nested stack ultimately belongs.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackId → String?
Unique stack identifier.
final
stackName → String
The name associated with the stack.
final
stackStatus → StackStatus
The current status of the stack.
final
stackStatusReason → String?
Success/Failure message associated with the stack status.
final
templateDescription → String?
The template description of the template used to create the stack.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited