ValidateTemplateOutput class

The output for ValidateTemplate action.

Constructors

ValidateTemplateOutput({List<Capability>? capabilities, String? capabilitiesReason, List<String>? declaredTransforms, String? description, List<TemplateParameter>? parameters})
ValidateTemplateOutput.fromXml(XmlElement elem)
factory

Properties

capabilities → List<Capability>?
The capabilities found within the template. If your template contains IAM resources, you must specify the CAPABILITY_IAM or CAPABILITY_NAMED_IAM value for this parameter when you use the CreateStack or UpdateStack actions with your template; otherwise, those actions return an InsufficientCapabilities error.
final
capabilitiesReason → String?
The list of resources that generated the values in the Capabilities response element.
final
declaredTransforms → List<String>?
A list of the transforms that are declared in the template.
final
description → String?
The description found within the template.
final
hashCode → int
The hash code for this object.
no setterinherited
parameters → List<TemplateParameter>?
A list of TemplateParameter structures.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited